You are viewing a plain text version of this content. The canonical link for it is here.
Posted to github@arrow.apache.org by "devinjdangelo (via GitHub)" <gi...@apache.org> on 2023/09/17 16:07:58 UTC

[GitHub] [arrow-datafusion] devinjdangelo commented on pull request #7563: Parallelize Parquet Serialization (Alternative Implementation)

devinjdangelo commented on PR #7563:
URL: https://github.com/apache/arrow-datafusion/pull/7563#issuecomment-1722509216

   This actually turned out to be ~10% faster and slightly lower memory usage in a release build. The approach from this PR is pulled into the main PR now, so I am closing this one as no longer needed.


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: github-unsubscribe@arrow.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org